#ifndef NT2_INCLUDE_FUNCTIONS_ISINSIDE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISINSIDE_HPP_INCLUDED

#include <nt2/predicates/include/functions/isinside.hpp>

#endif
